pub struct ResolveServiceRequest {
pub endpoint_filter: Option<String>,
pub max_endpoints: Option<i32>,
}Expand description
The request message for LookupService.ResolveService. Looks up a service by its name, returns the service and its endpoints.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
endpoint_filter: Option<String>Optional. The filter applied to the endpoints of the resolved service. General filter string syntax: () * can be `name`, `address`, `port`, or `metadata.` for map field * can be <, >, <=, >=, !=, =, :. Of which : means HAS, and is roughly the same as = * must be the same data type as field * can be AND, OR, NOT Examples of valid filters: * metadata.owner returns endpoints that have a annotation with the key owner, this is the same as metadata:owner * metadata.protocol=gRPC returns endpoints that have key/value protocol=gRPC * address=192.108.1.105 returns endpoints that have this address * port>8080 returns endpoints that have port number larger than 8080 * name>projects/my-project/locations/us-east1/namespaces/my-namespace/services/my-service/endpoints/endpoint-c returns endpoints that have name that is alphabetically later than the string, so “endpoint-e” is returned but “endpoint-a” is not * name=projects/my-project/locations/us-central1/namespaces/my-namespace/services/my-service/endpoints/ep-1 returns the endpoint that has an endpoint_id equal to ep-1 * metadata.owner!=sd AND metadata.foo=bar returns endpoints that have owner in annotation key but value is not sd AND have key/value foo=bar * doesnotexist.foo=bar returns an empty list. Note that endpoint doesn’t have a field called “doesnotexist”. Since the filter does not match any endpoint, it returns no results For more information about filtering, see API Filtering.
max_endpoints: Option<i32>Optional. The maximum number of endpoints to return. Defaults to 25. Maximum is 100. If a value less than one is specified, the Default is used. If a value greater than the Maximum is specified, the Maximum is used.